@@ -1,21 +1,18 @@
 {-# LANGUAGE CPP                 #-}
 {-# LANGUAGE OverloadedStrings   #-}
 {-# LANGUAGE ScopedTypeVariables #-}
-import Criterion.Main
+import Test.Tasty.Bench
 import Data.Text (Text)
 import Data.Functor.Identity  -- base >= 4.8
 import Commonmark
 import Commonmark.Extensions
 import qualified Data.Text as T
 import qualified Data.Text.IO as TIO
-#if !MIN_VERSION_base(4,11,0)
-import Data.Monoid
-#endif
 
 main :: IO ()
 main = do
   sample <- T.replicate 10 <$> TIO.readFile "benchmark/sample.md"
-  defaultMainWith defaultConfig
+  defaultMain
     [ benchCommonmark (smartPunctuationSpec <> defaultSyntaxSpec)
         ("commonmark +smart", sample)
     , benchCommonmark (autolinkSpec <> defaultSyntaxSpec)
